@@ -1,7 +1,6 @@
-# coding: utf-8
+from datetime import datetime
 
 import pytest
-from datetime import datetime
 
 
 @pytest.fixture
@@ -16,9 +15,9 @@ def campaign_machine():
 
     class CampaignMachine(StateMachine):
         "A workflow machine"
-        draft = State('Draft', initial=True)
-        producing = State('Being produced')
-        closed = State('Closed')
+        draft = State("Draft", initial=True)
+        producing = State("Being produced")
+        closed = State("Closed")
 
         add_job = draft.to(draft) | producing.to(producing)
         produce = draft.to(producing)
@@ -28,20 +27,24 @@ def campaign_machine():
 
 
 @pytest.fixture
-def campaign_machine_with_invalid_final_state_transition():
+def campaign_machine_with_validator():
     "Define a new class for each test"
     from statemachine import State, StateMachine
 
     class CampaignMachine(StateMachine):
         "A workflow machine"
-        draft = State('Draft', initial=True)
-        producing = State('Being produced')
-        closed = State('Closed', final=True)
+        draft = State("Draft", initial=True)
+        producing = State("Being produced")
+        closed = State("Closed")
 
-        add_job = draft.to(draft) | producing.to(producing) | closed.to(draft)
-        produce = draft.to(producing)
+        add_job = draft.to(draft) | producing.to(producing)
+        produce = draft.to(producing, validators="can_produce")
         deliver = producing.to(closed)
 
+        def can_produce(*args, **kwargs):
+            if "goods" not in kwargs:
+                raise LookupError("Goods not found.")
+
     return CampaignMachine
 
 
@@ -52,9 +55,9 @@ def campaign_machine_with_final_state():
 
     class CampaignMachine(StateMachine):
         "A workflow machine"
-        draft = State('Draft', initial=True)
-        producing = State('Being produced')
-        closed = State('Closed', final=True)
+        draft = State("Draft", initial=True)
+        producing = State("Being produced")
+        closed = State("Closed", final=True)
 
         add_job = draft.to(draft) | producing.to(producing)
         produce = draft.to(producing)
@@ -70,9 +73,9 @@ def campaign_machine_with_values():
 
     class CampaignMachineWithKeys(StateMachine):
         "A workflow machine"
-        draft = State('Draft', initial=True, value=1)
-        producing = State('Being produced', value=2)
-        closed = State('Closed', value=3)
+        draft = State("Draft", initial=True, value=1)
+        producing = State("Being produced", value=2)
+        closed = State("Closed", value=3)
 
         add_job = draft.to(draft) | producing.to(producing)
         produce = draft.to(producing)
@@ -83,30 +86,42 @@ def campaign_machine_with_values():
 
 @pytest.fixture
 def traffic_light_machine():
+    from tests.examples.traffic_light_machine import TrafficLightMachine
+
+    return TrafficLightMachine
+
+
+@pytest.fixture
+def OrderControl():
+    from tests.examples.order_control_machine import OrderControl
+
+    return OrderControl
+
+
+@pytest.fixture
+def AllActionsMachine():
+    from tests.examples.all_actions_machine import AllActionsMachine
+
+    return AllActionsMachine
+
+
+@pytest.fixture(autouse=True)
+def add_machines_to_doctest(doctest_namespace, traffic_light_machine):
+    doctest_namespace["TrafficLightMachine"] = traffic_light_machine
+
+
+@pytest.fixture
+def classic_traffic_light_machine():
     from statemachine import StateMachine, State
 
     class TrafficLightMachine(StateMachine):
-        "A traffic light machine"
-        green = State('Green', initial=True)
-        yellow = State('Yellow')
-        red = State('Red')
+        green = State("Green", initial=True)
+        yellow = State("Yellow")
+        red = State("Red")
 
-        cycle = green.to(yellow) | yellow.to(red) | red.to(green)
-
-        @green.to(yellow)
-        def slowdown(self, *args, **kwargs):
-            return args, kwargs
-
-        @yellow.to(red)
-        def stop(self, *args, **kwargs):
-            return args, kwargs
-
-        @red.to(green)
-        def go(self, *args, **kwargs):
-            return args, kwargs
-
-        def on_cycle(self, *args, **kwargs):
-            return args, kwargs
+        slowdown = green.to(yellow)
+        stop = yellow.to(red)
+        go = red.to(green)
 
     return TrafficLightMachine
 
@@ -117,12 +132,17 @@ def reverse_traffic_light_machine():
 
     class ReverseTrafficLightMachine(StateMachine):
         "A traffic light machine"
-        green = State('Green', initial=True)
-        yellow = State('Yellow')
-        red = State('Red')
+        green = State("Green", initial=True)
+        yellow = State("Yellow")
+        red = State("Red")
 
         stop = red.from_(yellow, green, red)
-        cycle = green.from_(red) | yellow.from_(green) | red.from_(yellow) | red.from_.itself()
+        cycle = (
+            green.from_(red)
+            | yellow.from_(green)
+            | red.from_(yellow)
+            | red.from_.itself()
+        )
 
     return ReverseTrafficLightMachine
 
@@ -133,20 +153,22 @@ def approval_machine(current_time):
 
     class ApprovalMachine(StateMachine):
         "A workflow machine"
-        requested = State('Requested', initial=True)
-        accepted = State('Accepted')
-        rejected = State('Rejected')
+        requested = State("Requested", initial=True)
+        accepted = State("Accepted")
+        rejected = State("Rejected")
 
-        completed = State('Completed')
+        completed = State("Completed")
 
-        @requested.to(accepted, rejected)
-        def validate(self, *args, **kwargs):
+        validate = requested.to(accepted, cond="is_ok") | requested.to(rejected)
+
+        @validate
+        def do_validate(self, *args, **kwargs):
             if self.model.is_ok():
                 self.model.accepted_at = current_time
-                return self.model, self.accepted
+                return self.model
             else:
                 self.model.rejected_at = current_time
-                return self.model, self.rejected
+                return self.model
 
         @accepted.to(completed)
         def complete(self):
